@@ -44,6 +44,7 @@ public:
     QStringList mimeTypes;
     QStringList capabilities;
     QStringList excludeCapabilities;
+    bool filterAcceptRegExp(const QModelIndex &index, const QRegExp &filterRegExpStr);
 };
 
 AgentFilterProxyModel::AgentFilterProxyModel(QObject *parent)
@@ -84,20 +85,24 @@ void AgentFilterProxyModel::clearFilters()
     invalidateFilter();
 }
 
-bool AgentFilterProxyModel::filterAcceptsRow(int row, const QModelIndex &) const
+bool AgentFilterProxyModel::Private::filterAcceptRegExp(const QModelIndex &index, const QRegExp &filterRegExpStr)
 {
-    const QModelIndex index = sourceModel()->index(row, 0);
-
     // First see if the name matches a set regexp filter.
-    if (!filterRegExp().isEmpty()) {
-        if (index.data(AgentTypeModel::IdentifierRole).toString().contains(filterRegExp())) {
+    if (!filterRegExpStr.isEmpty()) {
+        if (index.data(AgentTypeModel::IdentifierRole).toString().contains(filterRegExpStr)) {
             return true;
-        } else if (index.data().toString().contains(filterRegExp())) {
+        } else if (index.data().toString().contains(filterRegExpStr)) {
             return true;
         } else {
             return false;
         }
     }
+    return true;
+}
+
+bool AgentFilterProxyModel::filterAcceptsRow(int row, const QModelIndex &) const
+{
+    const QModelIndex index = sourceModel()->index(row, 0);
 
     if (!d->mimeTypes.isEmpty()) {
         bool found = false;
@@ -117,6 +122,7 @@ bool AgentFilterProxyModel::filterAcceptsRow(int row, const QModelIndex &) const
             }
 
             if (found) {
+                found = d->filterAcceptRegExp(index, filterRegExp());
                 break;
             }
         }
@@ -124,6 +130,8 @@ bool AgentFilterProxyModel::filterAcceptsRow(int row, const QModelIndex &) const
         if (!found) {
             return false;
         }
+    } else {
+        return d->filterAcceptRegExp(index, filterRegExp());
     }
 
     if (!d->capabilities.isEmpty()) {
@@ -149,6 +157,8 @@ bool AgentFilterProxyModel::filterAcceptsRow(int row, const QModelIndex &) const
 
             if (!found) {
                 return false;
+            } else {
+                return d->filterAcceptRegExp(index, filterRegExp());
             }
         }
     }
