@@ -32,7 +32,7 @@
 
 #include <kconfiggroup.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
 
